@@ -45,7 +45,25 @@ class VecTests: XCTestCase {
         XCTAssertEqual(vec.len(), 5)
         
         XCTAssertEqual(vec.get(index: 1), 9)
-        fatalError("Ran")
+    }
+    
+    func testVecOfOpaqueRustType() throws {
+        let vec = create_vec_opaque_rust_type()
+        
+        XCTAssertEqual(vec.len(), 1)
+        XCTAssertEqual(vec.get(index: 0)!.text().toString(), "hello there, friend")
+        
+        let popped = vec.pop()
+        XCTAssertEqual(popped?.text().toString(), "hello there, friend")
+        
+        XCTAssertEqual(vec.len(), 0)
+        XCTAssertNil(vec.pop())
+        XCTAssertNil(vec.get(index: 1))
+        
+        let text = "My pushed text"
+        vec.push(value: ARustTypeInsideVecT(text.toRustStr()))
+        XCTAssertEqual(vec.len(), 1)
+        XCTAssertEqual(vec.get(index: 0)!.text().toString(), "My pushed text")
     }
     
     func testRustVecIterator() throws {
@@ -64,7 +82,7 @@ class VecTests: XCTestCase {
     /// Here we call the rest of the types, confident that if we can construct them then the rest of their
     /// methods will work since they worked for the other types above.
     func testConstructPrimitiveRustVecs() throws {
-        XCTAssertEqual(RustVec<UInt8>().pop(), 0);
+        XCTAssertEqual(RustVec<UInt8>().pop(), nil);
         XCTAssertEqual(RustVec<UInt16>().len(), 0);
         XCTAssertEqual(RustVec<UInt32>().len(), 0);
         XCTAssertEqual(RustVec<UInt64>().len(), 0);
