@@ -34,12 +34,10 @@ fn core_swift() -> String {
 
     core_swift += include_str!("src/std_bridge/string.swift");
     core_swift += include_str!("src/std_bridge/rust_vec.swift");
-    core_swift += include_str!("src/std_bridge/option.swift");
 
     for path in vec![
         "src/std_bridge/string.swift",
         "src/std_bridge/rust_vec.swift",
-        "src/std_bridge/option.swift",
     ] {
         println!(
             "cargo:rerun-if-changed={}",
@@ -47,23 +45,22 @@ fn core_swift() -> String {
         )
     }
 
-    for (swift_ty, rust_ty, unused_value) in vec![
-        ("UInt8", "u8", "123"),
-        ("UInt16", "u16", "123"),
-        ("UInt32", "u32", "123"),
-        ("UInt64", "u64", "123"),
-        ("UInt", "usize", "123"),
+    for (swift_ty, rust_ty) in vec![
+        ("UInt8", "u8"),
+        ("UInt16", "u16"),
+        ("UInt32", "u32"),
+        ("UInt64", "u64"),
+        ("UInt", "usize"),
         //
-        ("Int8", "i8", "123"),
-        ("Int16", "i16", "123"),
-        ("Int32", "i32", "123"),
-        ("Int64", "i64", "123"),
-        ("Int", "isize", "123"),
+        ("Int8", "i8"),
+        ("Int16", "i16"),
+        ("Int32", "i32"),
+        ("Int64", "i64"),
+        ("Int", "isize"),
         //
-        ("Bool", "bool", "false"),
+        ("Bool", "bool"),
     ] {
         core_swift += &conform_to_vectorizable(swift_ty, rust_ty);
-        core_swift += &conform_to_ffi_option(swift_ty, unused_value);
     }
 
     core_swift
@@ -147,11 +144,6 @@ extension {swift_ty}: Vectorizable {{
     static func vecOfSelfLen(vecPtr: UnsafeMutableRawPointer) -> UInt {{
         __swift_bridge__$Vec_{rust_ty}$len(vecPtr)
     }}
-    
-    static func vecOfSelfAsPtr(vecPtr: UnsafeMutableRawPointer) -> UnsafePointer<Self> {{
-        UnsafePointer(__swift_bridge__$Vec_{rust_ty}$as_ptr(vecPtr))
-    }}
-
 }}
     "#,
         rust_ty = rust_ty,
@@ -159,20 +151,6 @@ extension {swift_ty}: Vectorizable {{
     )
 }
 
-fn conform_to_ffi_option(swift_ty: &str, unused_value: &str) -> String {
-    format!(
-        r#"
-extension {swift_ty}: FfiOption {{
-    static func unusedValue() -> Self {{
-        {value}
-    }}
-}}
-    "#,
-        swift_ty = swift_ty,
-        value = unused_value
-    )
-}
-
 fn manifest_dir() -> PathBuf {
     PathBuf::from(env!("CARGO_MANIFEST_DIR"))
 }
